@@ -13,7 +13,7 @@
 
 #include <KCalUtils/IncidenceFormatter>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QLocale>
 
@@ -39,6 +39,8 @@ QString KAEventFormatter::label(Parameter param)
         return i18nc("@label", "Alarm type");
     case AlarmCategory:
         return i18nc("@label", "Alarm status");
+    case Name:
+        return i18nc("@label", "Alarm name");
     case TemplateName:
         return i18nc("@label", "Template name");
     case CreatedTime:
@@ -118,6 +120,8 @@ QString KAEventFormatter::label(Parameter param)
         return i18nc("@label Whether the alarm has a reminder", "Reminder");
     case ReminderOnce:
         return i18nc("@label Whether reminder is on first recurrence only", "Reminder once only");
+    case Notify:
+        return i18nc("@label Whether to use standard notification system", "Notify");
     case DeferralType:
         return i18nc("@label Deferral type", "Deferral");
     case DeferralTime:
@@ -158,6 +162,7 @@ bool KAEventFormatter::isApplicable(Parameter param) const
     case Id:
     case AlarmType:
     case AlarmCategory:
+    case Name:
     case CreatedTime:
     case StartTime:
     case Recurs:
@@ -197,6 +202,7 @@ bool KAEventFormatter::isApplicable(Parameter param) const
     case ConfirmAck:
     case AkonadiItem:
     case Reminder:
+    case Notify:
     case DeferralType:
     case DeferDefault:
         return mEvent.actionTypes() & KAEvent::ACT_DISPLAY;
@@ -269,8 +275,9 @@ QString KAEventFormatter::value(Parameter param) const
             break;
         }
         break;
+    case Name:
     case TemplateName:
-        return mEvent.templateName();
+        return mEvent.name();
     case CreatedTime:
         return mEvent.createdDateTime().toUtc().toString(QStringLiteral("%Y-%m-%d %H:%M:%SZ"));
     case StartTime:
@@ -351,6 +358,8 @@ QString KAEventFormatter::value(Parameter param) const
         return mEvent.reminderMinutes() ? minutesHoursDays(mEvent.reminderMinutes()) : trueFalse(false);
     case ReminderOnce:
         return trueFalse(mEvent.reminderOnceOnly());
+    case Notify:
+        return trueFalse(mEvent.notify());
     case DeferralType:
         return mEvent.reminderDeferral() ? i18nc("@info", "Reminder") : trueFalse(mEvent.deferred());
     case DeferralTime:
