@@ -16,11 +16,10 @@
 #include "kacalendar.h"
 #include "repetition.h"
 
-#include <collection.h>
-#include <item.h>
-#include <KCalendarCore/Person>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 #include <KCalendarCore/Calendar>
-#include <AkonadiCore/item.h>
+#include <KCalendarCore/Person>
 
 #include <QBitArray>
 #include <QColor>
@@ -828,7 +827,7 @@ public:
 
     /** Return the number of minutes (>= 0) after the default alarm time which is
      *  specified in the alarm template. If this is specified, an alarm based on
-     *  this template wll have the "Time from now" radio button enabled in the alarm
+     *  this template will have the "Time from now" radio button enabled in the alarm
      *  edit dialog.
      *  @return minutes after the default time, or -1 if the template specifies a time
      *          of day or a date-only alarm.
