@@ -7,8 +7,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KALARM_KARECURRENCE_H
-#define KALARM_KARECURRENCE_H
+#pragma once
 
 #include "kalarmcal_export.h"
 #include "kadatetime.h"
@@ -291,7 +290,7 @@ public:
      * Example: pos = 2, and bits 0 and 2 are set in days
      *   If months are specified (via addYearlyMonth), e.g. March, the rule is
      *   to repeat every year on the 2nd Monday and Wednesday of March.
-     *   If no months are specified, the fule is to repeat every year on the
+     *   If no months are specified, the rule is to repeat every year on the
      *   2nd Monday and Wednesday of the year.
      */
     void addYearlyPos(short pos, const QBitArray &days);
@@ -446,6 +445,5 @@ private:
 
 } // namespace KAlarmCal
 
-#endif // KALARM_KARECURRENCE_H
 
 // vim: et sw=4:
